@@ -5,6 +5,13 @@ import numpy.testing as npt
 import pytest
 from lenstronomy.LensModel.single_plane import SinglePlane
 from lenstronomy.LensModel.Profiles.sis import SIS
+import unittest
+
+try:
+    import fastell4py
+    bool_test = True
+except:
+    bool_test = False
 
 
 class TestLensModel(object):
@@ -45,8 +52,8 @@ class TestLensModel(object):
         npt.assert_almost_equal(density, density_model, decimal=8)
 
     def test_bool_list(self):
-        lensModel = SinglePlane(['SPEMD', 'SHEAR'])
-        kwargs = [{'theta_E': 1, 'gamma': 1, 'e1': 0.1, 'e2': -0.1, 'center_x': 0, 'center_y': 0},
+        lensModel = SinglePlane(['SPEP', 'SHEAR'])
+        kwargs = [{'theta_E': 1, 'gamma': 2, 'e1': 0.1, 'e2': -0.1, 'center_x': 0, 'center_y': 0},
                            {'gamma1': 0.01, 'gamma2': -0.02}]
         alphax_1, alphay_1 = lensModel.alpha(1, 1, kwargs, k=0)
         alphax_1_list, alphay_1_list = lensModel.alpha(1, 1, kwargs, k=[0])
@@ -60,11 +67,28 @@ class TestLensModel(object):
         npt.assert_almost_equal(alphay_1_1 + alphay_1_2, alphay_full, decimal=5)
 
     def test_init(self):
-        lens_model_list = ['TNFW', 'SPEMD_SMOOTH', 'TRIPLE_CHAMELEON', 'SHEAR_GAMMA_PSI', 'CURVED_ARC', 'NFW_MC',
+        lens_model_list = ['TNFW', 'TRIPLE_CHAMELEON', 'SHEAR_GAMMA_PSI', 'CURVED_ARC', 'NFW_MC',
                            'ARC_PERT']
         lensModel = SinglePlane(lens_model_list=lens_model_list)
         assert lensModel.func_list[0].param_names[0] == 'Rs'
 
 
+class TestRaise(unittest.TestCase):
+
+    def test_raise(self):
+        """
+        check whether raises occurs if fastell4py is not installed
+
+        :return:
+        """
+        if bool_test is False:
+            with self.assertRaises(ImportError):
+                SinglePlane(lens_model_list=['PEMD'])
+            with self.assertRaises(ImportError):
+                SinglePlane(lens_model_list=['SPEMD'])
+        else:
+            SinglePlane(lens_model_list=['PEMD', 'SPEMD'])
+
+
 if __name__ == '__main__':
     pytest.main("-k TestLensModel")
