@@ -313,6 +313,33 @@ def test_points_on_circle():
     assert dec[0] == 0
 
 
+def test_convert_bool_list():
+    bool_list = util.convert_bool_list(n=10, k=None)
+    assert len(bool_list) == 10
+    assert bool_list[0] == True
+
+    bool_list = util.convert_bool_list(n=10, k=3)
+    assert len(bool_list) == 10
+    assert bool_list[3] is True
+    assert bool_list[2] is False
+
+    bool_list = util.convert_bool_list(n=10, k=[3, 7])
+    assert len(bool_list) == 10
+    assert bool_list[3] is True
+    assert bool_list[7] is True
+    assert bool_list[2] is False
+
+    bool_list = util.convert_bool_list(n=3, k=[False, False, True])
+    assert len(bool_list) == 3
+    assert bool_list[0] is False
+    assert bool_list[1] is False
+    assert bool_list[2] is True
+
+    bool_list = util.convert_bool_list(n=3, k=[])
+    assert len(bool_list) == 3
+    assert bool_list[0] is False
+
+
 class TestRaise(unittest.TestCase):
 
     def test_raise(self):
@@ -326,6 +353,12 @@ class TestRaise(unittest.TestCase):
             util.selectBest(array=np.ones(6), criteria=np.ones(5), numSelect=1, highest=True)
         with self.assertRaises(ValueError):
             util.select_best(array=np.ones(6), criteria=np.ones(5), num_select=1, highest=True)
+        with self.assertRaises(ValueError):
+            util.convert_bool_list(n=2, k=[3, 7])
+        with self.assertRaises(ValueError):
+            util.convert_bool_list(n=3, k=[True, True])
+        with self.assertRaises(ValueError):
+            util.convert_bool_list(n=2, k=[0.1, True])
 
 
 if __name__ == '__main__':
